==> modeldb-sqlite-expo-0.13.0.tgz: package/lib/ModelDB.js <==
var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a getter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
    return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
};
var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {
    if (kind === "m") throw new TypeError("Private method is not writable");
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a setter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot write private member to an object whose class did not declare it");
    return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
};
var _ModelDB_models, _ModelDB_transaction;
import * as SQLite from "expo-sqlite";
import { assert, signalInvalidType } from "@canvas-js/utils";
import { AbstractModelDB, parseConfig, } from "@canvas-js/modeldb";
import { ModelAPI } from "./api.js";
export class ModelDB extends AbstractModelDB {
    constructor({ path, models }) {
        super(parseConfig(models));
        Object.defineProperty(this, "db", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        _ModelDB_models.set(this, {});
        _ModelDB_transaction.set(this, void 0);
        this.db = SQLite.openDatabaseSync(path ?? ':memory:');
        for (const model of Object.values(this.models)) {
            __classPrivateFieldGet(this, _ModelDB_models, "f")[model.name] = new ModelAPI(this.db, model);
        }
        __classPrivateFieldSet(this, _ModelDB_transaction, (effects) => this.db.withTransactionSync(() => {
            for (const effect of effects) {
                const model = this.models[effect.model];
                assert(model !== undefined, `model ${effect.model} not found`);
                if (effect.operation === "set") {
                    __classPrivateFieldGet(this, _ModelDB_models, "f")[effect.model].set(effect.value);
                }
                else if (effect.operation === "delete") {
                    __classPrivateFieldGet(this, _ModelDB_models, "f")[effect.model].delete(effect.key);
                }
                else {
                    signalInvalidType(effect);
                }
            }
        }), "f");
    }
    async close() {
        this.log("closing");
        this.db.closeSync();
    }
    async apply(effects) {
        __classPrivateFieldGet(this, _ModelDB_transaction, "f").call(this, effects);
        for (const { model, query, filter, callback } of this.subscriptions.values()) {
            if (effects.some(filter)) {
                const api = __classPrivateFieldGet(this, _ModelDB_models, "f")[model];
                assert(api !== undefined, `model ${model} not found`);
                try {
                    callback(api.query(query));
                }
                catch (err) {
                    this.log.error(err);
                }
            }
        }
    }
    async get(modelName, key) {
        const api = __classPrivateFieldGet(this, _ModelDB_models, "f")[modelName];
        assert(api !== undefined, `model ${modelName} not found`);
        return api.get(key);
    }
    async getMany(modelName, keys) {
        const api = __classPrivateFieldGet(this, _ModelDB_models, "f")[modelName];
        assert(api !== undefined, `model ${modelName} not found`);
        return api.getMany(keys);
    }
    async *iterate(modelName, query = {}) {
        const api = __classPrivateFieldGet(this, _ModelDB_models, "f")[modelName];
        assert(api !== undefined, `model ${modelName} not found`);
        yield* api.iterate(query);
    }
    async count(modelName, where) {
        const api = __classPrivateFieldGet(this, _ModelDB_models, "f")[modelName];
        assert(api !== undefined, `model ${modelName} not found`);
        return api.count(where);
    }
    async clear(modelName) {
        const api = __classPrivateFieldGet(this, _ModelDB_models, "f")[modelName];
        assert(api !== undefined, `model ${modelName} not found`);
        return api.clear();
    }
    async query(modelName, query = {}) {
        const api = __classPrivateFieldGet(this, _ModelDB_models, "f")[modelName];
        assert(api !== undefined, `model ${modelName} not found`);
        return api.query(query);
    }
}
_ModelDB_models = new WeakMap(), _ModelDB_transaction = new WeakMap();

==> modeldb-sqlite-expo-0.13.9.tgz: package/lib/ModelDB.js <==
var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a getter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
    return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
};
var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {
    if (kind === "m") throw new TypeError("Private method is not writable");
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a setter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot write private member to an object whose class did not declare it");
    return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
};
var _ModelDB_models, _ModelDB_transaction;
import * as SQLite from "expo-sqlite";
import { assert, signalInvalidType } from "@canvas-js/utils";
import { AbstractModelDB, parseConfig, } from "@canvas-js/modeldb";
import { ModelAPI } from "./api.js";
export class ModelDB extends AbstractModelDB {
    constructor({ path, models, clear }) {
        super(parseConfig(models));
        Object.defineProperty(this, "db", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        _ModelDB_models.set(this, {});
        _ModelDB_transaction.set(this, void 0);
        this.db = SQLite.openDatabaseSync(path ?? ":memory:");
        if (clear) {
            this.db.withTransactionSync(() => {
                const tables = this.db.getAllSync("SELECT name FROM sqlite_master WHERE type='table'");
                for (const table of tables) {
                    // execSync works inconsistently in expo, use runSync instead
                    if (table.name.includes("\\") || table.name.includes('"')) {
                        throw new Error("unexpected table name, try clearing your database using Expo/Drizzle");
                    }
                    this.db.runSync(`DROP TABLE IF EXISTS "${table.name}"`);
                }
            });
        }
        for (const model of Object.values(this.models)) {
            __classPrivateFieldGet(this, _ModelDB_models, "f")[model.name] = new ModelAPI(this.db, model);
        }
        __classPrivateFieldSet(this, _ModelDB_transaction, (effects) => this.db.withTransactionSync(() => {
            for (const effect of effects) {
                const model = this.models[effect.model];
                assert(model !== undefined, `model ${effect.model} not found`);
                if (effect.operation === "set") {
                    __classPrivateFieldGet(this, _ModelDB_models, "f")[effect.model].set(effect.value);
                }
                else if (effect.operation === "delete") {
                    __classPrivateFieldGet(this, _ModelDB_models, "f")[effect.model].delete(effect.key);
                }
                else {
                    signalInvalidType(effect);
                }
            }
        }), "f");
    }
    getType() {
        return "sqlite-expo";
    }
    async close() {
        this.log("closing");
        this.db.closeSync();
    }
    async apply(effects) {
        __classPrivateFieldGet(this, _ModelDB_transaction, "f").call(this, effects);
        for (const { model, query, filter, callback } of this.subscriptions.values()) {
            if (effects.some(filter)) {
                const api = __classPrivateFieldGet(this, _ModelDB_models, "f")[model];
                assert(api !== undefined, `model ${model} not found`);
                try {
                    callback(api.query(query));
                }
                catch (err) {
                    this.log.error(err);
                }
            }
        }
    }
    async get(modelName, key) {
        const api = __classPrivateFieldGet(this, _ModelDB_models, "f")[modelName];
        assert(api !== undefined, `model ${modelName} not found`);
        return api.get(key);
    }
    async getMany(modelName, keys) {
        const api = __classPrivateFieldGet(this, _ModelDB_models, "f")[modelName];
        assert(api !== undefined, `model ${modelName} not found`);
        return api.getMany(keys);
    }
    async *iterate(modelName, query = {}) {
        const api = __classPrivateFieldGet(this, _ModelDB_models, "f")[modelName];
        assert(api !== undefined, `model ${modelName} not found`);
        yield* api.iterate(query);
    }
    async count(modelName, where) {
        const api = __classPrivateFieldGet(this, _ModelDB_models, "f")[modelName];
        assert(api !== undefined, `model ${modelName} not found`);
        return api.count(where);
    }
    async clear(modelName) {
        const api = __classPrivateFieldGet(this, _ModelDB_models, "f")[modelName];
        assert(api !== undefined, `model ${modelName} not found`);
        return api.clear();
    }
    async query(modelName, query = {}) {
        const api = __classPrivateFieldGet(this, _ModelDB_models, "f")[modelName];
        assert(api !== undefined, `model ${modelName} not found`);
        return api.query(query);
    }
}
_ModelDB_models = new WeakMap(), _ModelDB_transaction = new WeakMap();
